@@ -1,3 +1,11 @@
+"""
+    Copyright (C) 2017-2018 Team Kodi
+    This file is part of Kodi - kodi.tv
+
+    SPDX-License-Identifier: GPL-3.0-only
+    See LICENSES/README.md for more information.
+"""
+
 from kodi_addon_checker.report import Record
 from kodi_addon_checker.reporter import Reporter, reporter
 
@@ -8,5 +16,5 @@ class ArrayReporter(Reporter):
         self.reports = []
 
     def report(self, report):
-        if type(report) is Record:
+        if isinstance(report, Record):
             self.reports.append(report)
